@@ -2,6 +2,7 @@
 set -e -u
 
 bytecompile=1
+pypyhome=/usr/lib/pypy
 
 usage() {
 	name=$(basename $0)
@@ -37,12 +38,12 @@ else
 	echo "Removing byte-compiled PyPy standard library..."
 fi
 
-find /usr/lib/pypy/lib-python -name '*.pyc' -delete
-find /usr/lib/pypy/lib-python -name '__pycache__' -delete
-find /usr/lib/pypy/lib-python -type d -empty -delete
+find $pypyhome/lib-python $pypyhome/lib_pypy -name '*.pyc' -delete
+find $pypyhome/lib-python $pypyhome/lib_pypy -name '__pycache__' -delete
+find $pypyhome/lib-python $pypyhome/lib_pypy -type d -empty -delete
 
 if [ $bytecompile -gt 0 ]; then
 	# We know that some files are going to fail to byte-compile:
 	# (e.g. bits of test suites that are intentionally invalid)
-	find /usr/lib/pypy/lib-python -name '*.py' | pypy -m py_compile - > /dev/null 2>/dev/null || true
+	find $pypyhome/lib-python $pypyhome/lib_pypy -name '*.py' | pypy -m py_compile - > /dev/null 2>/dev/null || true
 fi
